@@ -23,12 +23,15 @@
 - (instancetype)init
 {
     self = [super init];
-    if (self) {
+    if (self)
+    {
         _encoderFallback = HB_ACODEC_AC3;
         _trackSelectionLanguages = [[NSMutableArray alloc] init];
         _tracksArray = [[NSMutableArray alloc] init];
         _trackSelectionBehavior = HBAudioTrackSelectionBehaviorFirst;
         _container = HB_MUX_MKV;
+        _passthruName = NO;
+        _automaticNamingBehavior = HBAudioTrackAutomaticNamingBehaviorNone;
     }
     return self;
 }
@@ -124,6 +127,15 @@
     _allowMP3Passthru = allowMP3Passthru;
 }
 
+- (void)setAllowVorbisPassthru:(BOOL)allowVorbisPassthru
+{
+    if (allowVorbisPassthru != _allowVorbisPassthru)
+    {
+        [[self.undo prepareWithInvocationTarget:self] setAllowVorbisPassthru:_allowVorbisPassthru];
+    }
+    _allowVorbisPassthru = allowVorbisPassthru;
+}
+
 - (void)setAllowOpusPassthru:(BOOL)allowOpusPassthru
 {
     if (allowOpusPassthru != _allowOpusPassthru)
@@ -142,6 +154,15 @@
     _allowTrueHDPassthru = allowTrueHDPassthru;
 }
 
+- (void)setAllowALACPassthru:(BOOL)allowALACPassthru
+{
+    if (allowALACPassthru != _allowALACPassthru)
+    {
+        [[self.undo prepareWithInvocationTarget:self] setAllowALACPassthru:_allowALACPassthru];
+    }
+    _allowALACPassthru = allowALACPassthru;
+}
+
 - (void)setAllowFLACPassthru:(BOOL)allowFLACPassthru
 {
     if (allowFLACPassthru != _allowFLACPassthru)
@@ -190,6 +211,24 @@
     return fallbacks;
 }
 
+- (void)setPassthruName:(BOOL)passthruName
+{
+    if (passthruName != _passthruName)
+    {
+        [[self.undo prepareWithInvocationTarget:self] setPassthruName:_passthruName];
+    }
+    _passthruName = passthruName;
+}
+
+- (void)setautomaticNamingBehavior:(HBAudioTrackAutomaticNamingBehavior)automaticNamingBehavior
+{
+    if (automaticNamingBehavior != _automaticNamingBehavior)
+    {
+        [[self.undo prepareWithInvocationTarget:self] setautomaticNamingBehavior:_automaticNamingBehavior];
+    }
+    _automaticNamingBehavior = automaticNamingBehavior;
+}
+
 #pragma mark - HBPresetCoding
 
 - (BOOL)applyPreset:(HBPreset *)preset error:(NSError * __autoreleasing *)outError
@@ -250,6 +289,9 @@
                 case HB_ACODEC_EAC3_PASS:
                     self.allowEAC3Passthru = YES;
                     break;
+                case HB_ACODEC_ALAC_PASS:
+                    self.allowALACPassthru = YES;
+                    break;
                 case HB_ACODEC_FLAC_PASS:
                     self.allowFLACPassthru = YES;
                     break;
@@ -259,6 +301,9 @@
                 case HB_ACODEC_MP3_PASS:
                     self.allowMP3Passthru = YES;
                     break;
+                case HB_ACODEC_VORBIS_PASS:
+                    self.allowVorbisPassthru = YES;
+                    break;
                 case HB_ACODEC_OPUS_PASS:
                     self.allowOpusPassthru = YES;
                     break;
@@ -279,6 +324,25 @@
         self.encoderFallback = hb_audio_encoder_get_from_name([preset[@"AudioEncoderFallback"] UTF8String]);
     }
 
+    self.passthruName = [preset[@"AudioTrackNamePassthru"] boolValue];
+
+    NSString *automaticNamingBehavior = preset[@"AudioAutomaticNamingBehavior"];
+    if ([automaticNamingBehavior isKindOfClass:[NSString class]])
+    {
+        if ([automaticNamingBehavior isEqualToString:@"none"])
+        {
+            self.automaticNamingBehavior = HBAudioTrackAutomaticNamingBehaviorNone;
+        }
+        else if ([automaticNamingBehavior isEqualToString:@"unnamed"])
+        {
+            self.automaticNamingBehavior = HBAudioTrackAutomaticNamingBehaviorUnnamed;
+        }
+        else if ([automaticNamingBehavior isEqualToString:@"all"])
+        {
+            self.automaticNamingBehavior = HBAudioTrackAutomaticNamingBehaviorAll;
+        }
+    }
+
     while ([self countOfTracksArray])
     {
         [self removeObjectFromTracksArrayAtIndex:0];
@@ -369,6 +433,10 @@
     {
         [copyMask addObject:@(hb_audio_encoder_get_short_name(HB_ACODEC_MP3_PASS))];
     }
+    if (self.allowVorbisPassthru)
+    {
+        [copyMask addObject:@(hb_audio_encoder_get_short_name(HB_ACODEC_VORBIS_PASS))];
+    }
     if (self.allowOpusPassthru)
     {
         [copyMask addObject:@(hb_audio_encoder_get_short_name(HB_ACODEC_OPUS_PASS))];
@@ -377,6 +445,10 @@
     {
         [copyMask addObject:@(hb_audio_encoder_get_short_name(HB_ACODEC_TRUEHD_PASS))];
     }
+    if (self.allowALACPassthru)
+    {
+        [copyMask addObject:@(hb_audio_encoder_get_short_name(HB_ACODEC_ALAC_PASS))];
+    }
     if (self.allowFLACPassthru)
     {
         [copyMask addObject:@(hb_audio_encoder_get_short_name(HB_ACODEC_FLAC_PASS))];
@@ -387,6 +459,22 @@
 
     preset[@"AudioSecondaryEncoderMode"] = @(self.secondaryEncoderMode);
 
+    preset[@"AudioTrackNamePassthru"] = @(self.passthruName);
+
+    switch (self.automaticNamingBehavior)
+    {
+        case HBAudioTrackAutomaticNamingBehaviorNone:
+            preset[@"AudioAutomaticNamingBehavior"] = @"none";
+            break;
+        case HBAudioTrackAutomaticNamingBehaviorUnnamed:
+            preset[@"AudioAutomaticNamingBehavior"] = @"unnamed";
+            break;
+        case HBAudioTrackAutomaticNamingBehaviorAll:
+        default:
+            preset[@"AudioAutomaticNamingBehavior"] = @"all";
+            break;
+    }
+
     NSMutableArray<NSDictionary *> *audioList = [[NSMutableArray alloc] init];
 
     for (HBAudioTrackPreset *track in self.tracksArray)
@@ -472,6 +560,9 @@
         copy->_encoderFallback = _encoderFallback;
         copy->_container = _container;
         copy->_secondaryEncoderMode = _secondaryEncoderMode;
+
+        copy->_passthruName = _passthruName;
+        copy->_automaticNamingBehavior = _automaticNamingBehavior;
     }
 
     return copy;
@@ -507,6 +598,9 @@
     encodeInt(_encoderFallback);
     encodeInt(_container);
     encodeBool(_secondaryEncoderMode);
+
+    encodeBool(_passthruName);
+    encodeInteger(_automaticNamingBehavior);
 }
 
 - (instancetype)initWithCoder:(NSCoder *)decoder
@@ -537,6 +631,14 @@
     decodeInt(_container); if (_container != HB_MUX_MP4 && _container != HB_MUX_MKV && _container != HB_MUX_WEBM) { goto fail; }
     decodeBool(_secondaryEncoderMode);
 
+    decodeBool(_passthruName);
+    decodeInt(_automaticNamingBehavior);
+    if (_automaticNamingBehavior < HBAudioTrackAutomaticNamingBehaviorNone || _automaticNamingBehavior > HBAudioTrackAutomaticNamingBehaviorAll)
+    {
+        goto fail;
+    }
+
+
     return self;
 
 fail:
