@@ -12,6 +12,7 @@ namespace HandBrake.Interop.Interop
     using System;
     using System.Collections.Generic;
     using System.Linq;
+    using System.Runtime.InteropServices;
 
     using HandBrake.Interop.Interop.HbLib;
     using HandBrake.Interop.Interop.Helpers;
@@ -88,7 +89,7 @@ namespace HandBrake.Interop.Interop
                 return videoFramerates;
             }
         }
-
+        
         /// <summary>
         /// Gets a list of supported mixdowns.
         /// </summary>
@@ -379,7 +380,7 @@ namespace HandBrake.Interop.Interop
         /// <returns>
         /// True if the subtitle type can be passed through with the given muxer.
         /// </returns>
-        public static bool SubtitleCanPassthrough(int subtitleSourceType, int muxer)
+        public static bool SubtitleCanPassthru(int subtitleSourceType, int muxer)
         {
             return HBFunctions.hb_subtitle_can_pass(subtitleSourceType, muxer) > 0;
         }
@@ -432,7 +433,7 @@ namespace HandBrake.Interop.Interop
         /// True if the given encoder is compatible with the given audio track.
         /// </returns>
         /// <remarks>
-        /// Only works with passthrough encoders.
+        /// Only works with passthru encoders.
         /// </remarks>
         public static bool AudioEncoderIsCompatible(int codecId, HBAudioEncoder encoder)
         {
@@ -518,7 +519,7 @@ namespace HandBrake.Interop.Interop
         /// <returns>
         /// True if the codec can be passed through.
         /// </returns>
-        public static bool CanPassthroughAudio(int codecId)
+        public static bool CanPassthruAudio(int codecId)
         {
             return (codecId & NativeConstants.HB_ACODEC_PASS_MASK) > 0;
         }
@@ -784,5 +785,12 @@ namespace HandBrake.Interop.Interop
 
             return new List<int>();
         }
+
+        public static string GetAutonameAudioTrack(string name, ulong layout, int mixdown, bool keep_name, int behaviour)
+        {
+            IntPtr nameptr = Marshal.StringToHGlobalAnsi(name);
+
+            return Marshal.PtrToStringUTF8((IntPtr)HBFunctions.hb_audio_name_generate(nameptr, layout, mixdown, keep_name ? 1 : 0, behaviour));
+        }
     }
 }
