@@ -1,32 +1,33 @@
 ﻿// --------------------------------------------------------------------------------------------------------------------
-// <copyright file="Color.cs" company="HandBrake Project (http://handbrake.fr)">
+// <copyright file="Color.cs" company="HandBrake Project (https://handbrake.fr)">
 //   This file is part of the HandBrake source code - It may be used under the terms of the GNU General Public License.
 // </copyright>
 // <summary>
-//   The color.
+//    Colour Information 
 // </summary>
 // --------------------------------------------------------------------------------------------------------------------
 
 namespace HandBrake.Interop.Interop.Json.Scan
 {
     /// <summary>
-    /// The color.
+    /// Colour Information 
     /// </summary>
     public class Color
     {
-        /// <summary>
-        /// Gets or sets the matrix.
-        /// </summary>
+        public int BitDepth { get; set; }
+
+        public int ChromaLocation { get; set; }
+
+        public string ChromaSubsampling { get; set; }
+
+        public int Format { get; set; }
+
         public int Matrix { get; set; }
 
-        /// <summary>
-        /// Gets or sets the primary.
-        /// </summary>
         public int Primary { get; set; }
 
-        /// <summary>
-        /// Gets or sets the transfer.
-        /// </summary>
+        public int Range { get; set; }
+
         public int Transfer { get; set; }
     }
 }
\ No newline at end of file
