@@ -53,11 +53,13 @@ namespace HandBrakeWPF
             AppDomain.CurrentDomain.ProcessExit += this.CurrentDomain_ProcessExit;
             
             ToolTipService.ShowDurationProperty.OverrideMetadata(typeof(DependencyObject), new FrameworkPropertyMetadata(15000));
+
+            SystemInfo.InitGPUInfo(); // Background Thread.
         }
 
         private void Init(StartupEventArgs e)
         {
-            if (!File.Exists("hb.dll") && !File.Exists(Path.Combine(AppDomain.CurrentDomain.BaseDirectory, "hb.dll")))
+            if (!SystemInfo.IsArmDevice && !File.Exists("hb.dll") && !File.Exists(Path.Combine(AppDomain.CurrentDomain.BaseDirectory, "hb.dll")))
             {
                 MessageBox.Show("hb.dll file not found. Application will not run correctly without this. Please re-install HandBrake.", "Error", MessageBoxButton.OK, MessageBoxImage.Error);
                 this.Shutdown();
@@ -65,6 +67,14 @@ namespace HandBrakeWPF
                 return;
             }
 
+            if (SystemInfo.IsArmDevice && !File.Exists("hb_a64.dll") && !File.Exists(Path.Combine(AppDomain.CurrentDomain.BaseDirectory, "hb_a64.dll")))
+            {
+                MessageBox.Show("hb_a64.dll file not found. Application will not run correctly without this. Please re-install HandBrake.", "Error", MessageBoxButton.OK, MessageBoxImage.Error);
+                this.Shutdown();
+                Environment.Exit(-1);
+                return;
+            }
+
             // We don't support Windows earlier than 10.
             if (!SystemInfo.IsWindows10OrLater())
             {
@@ -176,9 +186,7 @@ namespace HandBrakeWPF
 
             // App Theme
             DarkThemeMode useDarkTheme = (DarkThemeMode)userSettingService.GetUserSetting<int>(UserSettingConstants.DarkThemeMode);
-            ResourceDictionary dark = new ResourceDictionary { Source = new Uri("pack://application:,,,/MahApps.Metro;component/Styles/Themes/Dark.Blue.xaml") };
-            ResourceDictionary light = new ResourceDictionary { Source = new Uri("pack://application:,,,/MahApps.Metro;component/Styles/Themes/Light.Blue.xaml") };
-
+       
             Application.Current.Resources.MergedDictionaries.Add(new ResourceDictionary { Source = new Uri("Themes/Generic.xaml", UriKind.Relative) });
             bool themed = false;
             if (SystemParameters.HighContrast || !Portable.IsThemeEnabled())
@@ -193,24 +201,20 @@ namespace HandBrakeWPF
                 case DarkThemeMode.System:
                     if (SystemInfo.IsAppsUsingDarkTheme())
                     {
-                        Application.Current.Resources.MergedDictionaries.Add(dark);
                         Application.Current.Resources.MergedDictionaries.Add(new ResourceDictionary { Source = new Uri("Themes/Dark.xaml", UriKind.Relative) });
                     }
                     else
                     {
-                        Application.Current.Resources.MergedDictionaries.Add(light);
                         Application.Current.Resources.MergedDictionaries.Add(new ResourceDictionary { Source = new Uri("Themes/Light.xaml", UriKind.Relative) });
                     }
 
                     themed = true;
                     break;
                 case DarkThemeMode.Dark:
-                    Application.Current.Resources.MergedDictionaries.Add(dark);
                     Application.Current.Resources.MergedDictionaries.Add(new ResourceDictionary { Source = new Uri("Themes/Dark.xaml", UriKind.Relative) });
                     themed = true;
                     break;
                 case DarkThemeMode.Light:
-                    Application.Current.Resources.MergedDictionaries.Add(light);
                     Application.Current.Resources.MergedDictionaries.Add(new ResourceDictionary { Source = new Uri("Themes/Light.xaml", UriKind.Relative) });
                     themed = true;
                     break;
