@@ -29,7 +29,7 @@ namespace HandBrakeWPF.Utilities
                        new InterfaceLanguage("bg", "Bulgarian (Български)"),
                        new InterfaceLanguage("ca", "Catalan (Català)"),
                        new InterfaceLanguage("co", "Corsican (Corsu)"),
-                       new InterfaceLanguage("cs-CZ", "Czech (čeština)"),
+                       new InterfaceLanguage("gl-ES", "Galician (Galego)"),
                        new InterfaceLanguage("de", "German (Deutsch)"),
                        DefaultEnglishLanguage,
                        new InterfaceLanguage("el", "Greek (Ελληνικά)"),
@@ -39,6 +39,7 @@ namespace HandBrakeWPF.Utilities
                        new InterfaceLanguage("fa-IR", "Persian (Iran) (فارسی)"),
                        new InterfaceLanguage("fi", "Finnish (Suomi)"),
                        new InterfaceLanguage("fr", "French (Français)"),
+                       new InterfaceLanguage("hu", "Hungarian (Magyar)"),
                        new InterfaceLanguage("it", "Italian (Italiano)"),
                        new InterfaceLanguage("ja", "Japanese (日本語 (にほんご))"),
                        new InterfaceLanguage("ko", "Korean (한국어)"),
@@ -46,6 +47,7 @@ namespace HandBrakeWPF.Utilities
                        new InterfaceLanguage("pl", "Polish (Polski)"),
                        new InterfaceLanguage("pt-BR", "Brazilian Portuguese (Português do Brasil)"),
                        new InterfaceLanguage("ru", "Russian (Русский)"),
+                       new InterfaceLanguage("sv", "Swedish (Svenska)"),
                        new InterfaceLanguage("th", "Thai (ไทย)"),
                        new InterfaceLanguage("tr", "Turkish (Türkçe)"),
                        new InterfaceLanguage("uk", "Ukrainian (Українська)"),
