@@ -13,11 +13,13 @@ namespace HandBrakeWPF.Views
     using System.Diagnostics;
     using System.Windows;
     using System.Windows.Controls;
+    using System.Windows.Input;
 
-    using Caliburn.Micro;
+    using HandBrake.App.Core.Utilities;
 
+    using HandBrakeWPF.Commands;
+    using HandBrakeWPF.Helpers;
     using HandBrakeWPF.Services.Logging.EventArgs;
-    using HandBrakeWPF.Utilities;
     using HandBrakeWPF.ViewModels;
 
     public partial class LogView : Window
@@ -30,6 +32,13 @@ namespace HandBrakeWPF.Views
             this.InitializeComponent();
             this.DataContextChanged += this.LogView_DataContextChanged;
             this.Closed += this.LogView_Closed;
+            this.InputBindings.Add(new InputBinding(new CloseWindowCommand(this), new KeyGesture(Key.W, ModifierKeys.Control))); // Close Window
+        }
+
+        protected override void OnSourceInitialized(EventArgs e)
+        {
+            base.OnSourceInitialized(e);
+            WindowHelper.SetDarkMode(this);
         }
 
         private void LogView_Closed(object sender, EventArgs e)
@@ -52,7 +61,7 @@ namespace HandBrakeWPF.Views
 
         private void Vm_LogResetEvent(object sender, EventArgs e)
         {
-            Execute.OnUIThread(
+            ThreadHelper.OnUIThread(
                 () =>
                 {
                     this.logText.Clear();
@@ -69,7 +78,7 @@ namespace HandBrakeWPF.Views
 
                 if (this.AutoScroll.IsChecked)
                 {
-                    delayProcessor.PerformTask(() => Execute.BeginOnUIThread(() => this.logText.ScrollToEnd()), 100);
+                    delayProcessor.PerformTask(() => ThreadHelper.OnUIThread(() => this.logText.ScrollToEnd()), 100);
                 }
             }
             catch (Exception exc)
